@@ -13,11 +13,11 @@ Geo::Coder::List - Call many geocoders
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =cut
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 our %locations;
 
 =head1 SYNOPSIS
@@ -194,6 +194,11 @@ sub geocode {
 			next;
 		}
 		POSSIBLE_LOCATION: foreach my $l(@rc) {
+			if(ref($l) eq 'ARRAY') {
+				# Geo::GeoNames
+				# TODO: should consider all locations in the array
+				$l = $l->[0];
+			}
 			next if(ref($l) ne 'HASH');
 			if($l->{'error'}) {
 				my $log = {
@@ -209,7 +214,7 @@ sub geocode {
 			} else {
 				# Try to create a common interface, helps with HTML::GoogleMaps::V3
 				if(!defined($l->{geometry}{location}{lat})) {
-					if($l->{lat}) {
+					if($l->{lat} && defined($l->{lon})) {
 						# OSM/RandMcNalley
 						$l->{geometry}{location}{lat} = $l->{lat};
 						$l->{geometry}{location}{lng} = $l->{lon};
